// altered code for receiving data over an nrf24L01 chip
// https://www.circuitbasics.com/wireless-communication-between-two-arduinos/

#include <SPI.h>
#include <nRF24L01.h>
#include <RF24.h>
#include <Servo.h>

#define BAUDRATE 9600

// nrf24l01 chip constants
#define CE 9
#define CSN 8
#define ADDRESS "link1"

// servo1 constants
#define SERVO_PORT 3
#define SERVO_OFFEN 90
#define SERVO_GESCHLOSSEN 0

// status LED port
#define STATUS_LED 2

RF24 receiver(CE, CSN);  // nrf24l01 chip class used as a reciver

Servo drop;

const byte linkAddress[6] = ADDRESS;  //address through which two modules communicate.

/////////////////////////////////////////////////////////////////////

// öffnet den übergebenen servomoteo, wenn dieser nicht bereits geschlossen ist.
void openHatch(Servo hatch) {
  hatch.write(SERVO_OFFEN);

  delay(200);
}

// schließt den übergebenen servomoteo, wenn dieser nicht bereits geschlossen ist.
void closeHatch(Servo hatch) {
  hatch.write(SERVO_GESCHLOSSEN);

  delay(200);
}

void setup() {
  Serial.begin(BAUDRATE);
  Serial.println("\n------Startup-------");

  // set up the servomotor
  drop.attach(SERVO_PORT);
  drop.write(SERVO_GESCHLOSSEN);

  // set up status led
  pinMode(STATUS_LED, OUTPUT);

  // set up the nrf24 chip
  pinMode(CSN, OUTPUT);    // sets reciever CSN pin to output

  // tries to establish a connection between the nrf chip and the arduino.
  while (!receiver.begin(CE, CSN)) {
    Serial.println("Error while creating nrf driver instance. Try again.");
  }

  int data;
  receiver.openReadingPipe(0, linkAddress);  //set the receivers address
  receiver.startListening();                 //Set nrf as receiver

  // confirm startup success on serial monitor
  Serial.println("Startup complete!");


  // run the main programm until error
  while(true) {
    // handle no connection to SIP bus
  if (!receiver.isChipConnected()) {
    Serial.println("Error. receiver Chip is not connected to SIP bus.");
    return;
  } 
  else {
    // handle no data available
    if (!receiver.available()) {
      Serial.println("No data available.");
    }

    // collect data and print
    else {
      receiver.read(&data, sizeof(data));
      
      // switch hatch mode
      if (data == 1) {
        digitalWrite(STATUS_LED, LOW);
        drop.write(SERVO_OFFEN);
      }

      else {
        drop.write(SERVO_GESCHLOSSEN);
        digitalWrite(STATUS_LED, HIGH);
        Serial.println("B"); 
      }
      Serial.println(String(drop.read()));
    }
  }
  delay(300);
  }
}

///////////////////////////////////////////////////

// display malfunction on status LED
void loop() {
  digitalWrite(STATUS_LED, HIGH);
  delay(1000);
  digitalWrite(STATUS_LED, LOW);
  delay(500);
}
//////////////////////////////////////////////